@@ -7,7 +7,7 @@ use B::Hooks::EndOfScope;
 
 use Carp qw/croak/;
 
-our $VERSION = '0.000002';
+our $VERSION = '0.000003';
 
 sub import {
     my $class = shift;
@@ -136,10 +136,6 @@ __END__
 
 Test2::Plugin::SpecDeclare - Syntax keywords for L<Test2::Tools::Spec>.
 
-=head1 *** EXPERIMENTAL ***
-
-This distribution is experimental, anything can change at any time!
-
 =head1 DESCRIPTION
 
 This adds keywords for all the exports provided by L<Test2::Tools::Spec>. These
